@@ -1,8 +1,12 @@
+use 5.010001;
+use strict;
+use warnings;
+
 package Mite::MakeMaker;
 use Mite::Miteception;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.001001';
+our $VERSION   = '0.001002';
 
 ##-
 
@@ -10,7 +14,8 @@ use File::Find;
 use autodie;
 
 {
-    package MY;
+    package # hide from indexer
+        MY;
 
     sub top_targets {
         my $self = shift;
@@ -76,6 +81,9 @@ sub change_parent_dir {
     return $new_parent->child( $file->relative($old_parent) );
 }
 
+1;
+
+__END__
 
 =head1 NAME
 
@@ -117,10 +125,33 @@ dist> so all the mite files are picked up.
 The F<.mite> directory should not be shipped with your distribution.
 Add C<^\.mite/> to your F<MANIFEST.SKIP> file.
 
+=head1 BUGS
+
+Please report any bugs to L<https://github.com/tobyink/p5-mite/issues>.
+
 =head1 SEE ALSO
 
 L<Mite::ModuleBuild>
 
-=cut
+=head1 AUTHOR
 
-1;
+Michael G Schwern E<lt>mschwern@cpan.orgE<gt>.
+
+Toby Inkster E<lt>tobyink@cpan.orgE<gt>.
+
+=head1 COPYRIGHT AND LICENCE
+
+This software is copyright (c) 2011-2014 by Michael G Schwern.
+
+This software is copyright (c) 2022 by Toby Inkster.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=head1 DISCLAIMER OF WARRANTIES
+
+THIS PACKAGE IS PROVIDED "AS IS" AND WITHOUT ANY EXPRESS OR IMPLIED
+WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED WARRANTIES OF
+MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+
+=cut
