@@ -1,10 +1,11 @@
-package Mite::Miteception;
-use v5.10;
+use 5.010001;
 use strict;
 use warnings;
 
+package Mite::Miteception;
+
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.001001';
+our $VERSION   = '0.001002';
 
 my %constants;
 BEGIN {
@@ -130,3 +131,38 @@ sub load_mite_file {
 }
 
 1;
+
+__END__
+
+=pod
+
+=head1 NAME
+
+Mite::Miteception - Mite within a Mite
+
+=head1 DESCRIPTION
+
+NO USER SERVICABLE PARTS INSIDE.  This is a private class.
+
+=head1 BUGS
+
+Please report any bugs to L<https://github.com/tobyink/p5-mite/issues>.
+
+=head1 AUTHOR
+
+Toby Inkster E<lt>tobyink@cpan.orgE<gt>.
+
+=head1 COPYRIGHT AND LICENCE
+
+This software is copyright (c) 2022 by Toby Inkster.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=head1 DISCLAIMER OF WARRANTIES
+
+THIS PACKAGE IS PROVIDED "AS IS" AND WITHOUT ANY EXPRESS OR IMPLIED
+WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED WARRANTIES OF
+MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+
+=cut
